summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/okim6258.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/okim6258.cpp')
-rw-r--r--src/devices/sound/okim6258.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/devices/sound/okim6258.cpp b/src/devices/sound/okim6258.cpp
index 639c6fde50d..5f063f4cd87 100644
--- a/src/devices/sound/okim6258.cpp
+++ b/src/devices/sound/okim6258.cpp
@@ -114,7 +114,7 @@ void okim6258_device::device_start()
m_divider = dividers[m_start_divider];
- m_stream = stream_alloc(0, 1, clock()/m_divider);
+ m_stream = stream_alloc_legacy(0, 1, clock()/m_divider);
m_signal = -2;
m_step = 0;
@@ -138,10 +138,10 @@ void okim6258_device::device_reset()
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void okim6258_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void okim6258_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
stream_sample_t *buffer = outputs[0];
@@ -138,10 +138,10 @@ void okim6258_device::device_reset()
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------